==> webkitgtk-2.8.0.tar.xz: webkitgtk-2.8.0/Source/WebCore/css/LengthRepeat.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef LengthRepeat_h
#define LengthRepeat_h

#if ENABLE(CSS_SCROLL_SNAP)

#include "CSSPrimitiveValue.h"
#include <wtf/RefPtr.h>
#include <wtf/text/StringBuilder.h>

namespace WebCore {

class LengthRepeat : public RefCounted<LengthRepeat> {
public:
    static PassRefPtr<LengthRepeat> create(PassRefPtr<CSSPrimitiveValue> interval) { return adoptRef(new LengthRepeat(interval)); }

    PassRefPtr<LengthRepeat> cloneForCSSOM() const { return create(interval()); }

    CSSPrimitiveValue* interval() const { return m_interval.get(); }

    void setInterval(PassRefPtr<CSSPrimitiveValue> interval) { m_interval = interval; }

    bool equals(const LengthRepeat& other) const
    {
        return compareCSSValuePtr(m_interval, other.m_interval);
    }

    String cssText() const
    {
        return "repeat(" + interval()->cssText() + ")";
    }

private:
    LengthRepeat(PassRefPtr<CSSPrimitiveValue> interval)
        : m_interval(interval)
    {
    }

    RefPtr<CSSPrimitiveValue> m_interval;
};

} // namespace WebCore

#endif /* ENABLE(CSS_SCROLL_SNAP) */

#endif // LengthRepeat_h

==> webkitgtk-2.14.0.tar.xz: webkitgtk-2.14.0/Source/WebCore/css/LengthRepeat.h <==
/*
 * Copyright (C) 2014-2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef LengthRepeat_h
#define LengthRepeat_h

#if ENABLE(CSS_SCROLL_SNAP)

#include "CSSPrimitiveValue.h"
#include <wtf/RefPtr.h>
#include <wtf/text/StringBuilder.h>

namespace WebCore {

class LengthRepeat final : public RefCounted<LengthRepeat> {
public:
    static Ref<LengthRepeat> create(PassRefPtr<CSSValue> interval) { return adoptRef(*new LengthRepeat(interval)); }

    Ref<LengthRepeat> cloneForCSSOM() const { return create(interval()); }

    CSSValue* interval() const { return m_interval.get(); }

    void setInterval(PassRefPtr<CSSValue> interval) { m_interval = interval; }

    bool equals(const LengthRepeat& other) const
    {
        return compareCSSValuePtr(m_interval, other.m_interval);
    }

    String cssText() const
    {
        return "repeat(" + interval()->cssText() + ")";
    }

private:
    LengthRepeat(PassRefPtr<CSSValue> interval)
        : m_interval(interval)
    {
    }

    RefPtr<CSSValue> m_interval;
};

} // namespace WebCore

#endif /* ENABLE(CSS_SCROLL_SNAP) */

#endif // LengthRepeat_h
